@@ -194,8 +194,6 @@ source:
 """
 
 rest_main_template = """
-from cognite.extractorutils import Extractor
-
 from {name} import __version__
 from {name}.extractor import extractor
 
@@ -211,11 +209,13 @@ if __name__ == "__main__":
 
 rest_extractor_template = """
 import arrow
+
 from cognite.extractorutils.uploader_types import Event
+from cognite.extractorutils.rest.extractor import RestExtractor
 
+from {name} import __version__
 from {name}.dto import ElementList
 
-
 extractor = RestExtractor(
     name="{name}",
     description="{description}",
@@ -240,12 +240,84 @@ class MyElement:
     elementId: str
     eventTime: str
     duration: int
+    description: str
 
 @dataclass
 class ElementList:
     elements: List[MyElement]
 """
 
+mqtt_configfile_template = """
+logger:
+    console:
+        level: INFO
+
+cognite:
+    # Read these from environment variables
+    host: ${{COGNITE_BASE_URL}}
+    project: ${{COGNITE_PROJECT}}
+
+    idp-authentication:
+        token-url: ${{COGNITE_TOKEN_URL}}
+
+        client-id: ${{COGNITE_CLIENT_ID}}
+        secret: ${{COGNITE_CLIENT_SECRET}}
+        scopes:
+            - ${{COGNITE_BASE_URL}}/.default
+
+source:
+    username: mqtt-user
+    password: ${{MQTT_PASSWORD}}
+    client-id: my-extractor
+    host: mqtt://some-mqtt-broker
+"""
+
+mqtt_main_template = """
+from {name}.extractor import extractor
+
+def main() -> None:
+    with extractor:
+        extractor.run()
+
+if __name__ == "__main__":
+    main()
+"""
+
+mqtt_extractor_template = """
+import arrow
+
+from cognite.extractorutils.uploader_types import Event
+from cognite.extractorutils.mqtt.extractor import MqttExtractor
+
+from {name} import __version__
+from {name}.dto import EventFromMqtt
+
+extractor = MqttExtractor(
+    name="{name}",
+    description="{description}",
+    version=__version__,
+)
+
+@extractor.topic(topic="mytopic", qos=1, response_type=EventFromMqtt)
+def subscribe_events(evt: EventFromMqtt) -> Event:
+    start_time = arrow.get(evt.startTime)
+    end_time = start_time.shift(minutes=evt.duration)
+
+    return Event(start_time=start_time, end_time=end_time, description=evt.description)
+"""
+
+mqtt_dto_template = """
+from dataclasses import dataclass
+
+@dataclass
+class EventFromMqtt:
+    elementId: str
+    eventTime: str
+    duration: int
+    description: str
+"""
+
+
 rest_template: Dict[str, str] = {
     "example_config.yaml": rest_configfile_template,
     os.path.join("{name}", "extractor.py"): rest_extractor_template,
@@ -253,7 +325,14 @@ rest_template: Dict[str, str] = {
     os.path.join("{name}", "__main__.py"): rest_main_template,
 }
 
-templates: Dict[str, Dict[str, str]] = {"basic": basic_template, "rest": rest_template}
+mqtt_template: Dict[str, str] = {
+    "example_config.yaml": mqtt_configfile_template,
+    os.path.join("{name}", "extractor.py"): mqtt_extractor_template,
+    os.path.join("{name}", "dto.py"): mqtt_dto_template,
+    os.path.join("{name}", "__main__.py"): mqtt_main_template,
+}
+
+templates: Dict[str, Dict[str, str]] = {"basic": basic_template, "rest": rest_template, "mqtt": mqtt_template}
 
 
 def initialize_project() -> None:
@@ -267,7 +346,11 @@ def initialize_project() -> None:
         "  rest:  loads a template for extracting from RESTful APIs, using the REST\n"
         "         extension for extractor-utils"
     )
-    template = choice("template", ["basic", "rest"], "basic")
+    print(
+        "  mqtt:  loads a template for extracting data published by MQTT brokers, using\n"
+        "         the MQTT extension for extractor-utils"
+    )
+    template = choice("template", ["basic", "rest", "mqtt"], "basic")
 
     with open("pyproject.toml", "w") as pyproject_file:
         pyproject_file.write(pyproject_template.format(name=name, description=description, author=author))
@@ -294,6 +377,8 @@ def initialize_project() -> None:
     os.system("poetry add cognite-sdk-core cognite-extractor-utils")
     if template == "rest":
         os.system("poetry add cognite-extractor-utils-rest")
+    elif template == "mqtt":
+        os.system("poetry add cognite-extractor-utils-mqtt")
     os.system("poetry add -D mypy flake8 black isort pre-commit")
     os.system("poetry lock")
     os.system("poetry install")
